.. _cisco.nxos.nxos_httpapi:


***************
cisco.nxos.nxos
***************

**Use NX-API to run commands on Cisco NX-OS platform**


Version added: 1.0.0

.. contents::
   :local:
   :depth: 1


Synopsis
--------
- This plugin provides low level abstraction APIs for sending and receiving commands using NX-API with devices running Cisco NX-OS.











Status
------


Authors
~~~~~~~

- Ansible Networking Team


.. hint::
    Configuration entries for each entry type have a low to high priority order. For example, a variable that is lower in the list will override a variable that is higher up.
